#ifndef CMSCRIPTINGPLUGIN_H
#define CMSCRIPTINGPLUGIN_H

#ifndef CORESERVICES_H
#include <CoreServices/CoreServices.h>
#endif

#ifndef CMAPPLICATION_H
#include <ColorSync/CMApplication.h>
#endif


#include <AvailabilityMacros.h>

#if PRAGMA_ONCE
#pragma once
#endif

#ifdef __cplusplus
extern "C" {
#endif

/*CMGetIndImageProfile

Obtains a specific embeded profile for a given image. 

CMError CMGetIndImageProfile (
   const FSSpec * spec,
   UInt32 index,
   CMProfileRef * prof
);
Parameters
spec

A file specification for the image file. See the File Manager documentation for a description of the FSSpec data type.
index

The numeric index of the profile to return. 
prof

On output, points to the profile. 
Return Value

A CMError value. See “ColorSync Manager Result Codes”.
Availability
Available in CarbonLib 1.0 and later when ColorSync 2.6 or later is present. 
Declared In
CMScriptingPlugin.h*/
CMError CMGetIndImageProfile (
   const FSSpec * spec,
   UInt32 index,
   CMProfileRef * prof
);

/*CMEmbedImage

Embeds an image with an ICC profile. 

CMError CMEmbedImage (
   const FSSpec * specFrom,
   const FSSpec * specInto,
   Boolean repl,
   CMProfileRef embProf
);
Parameters
specFrom

A file specification for the image file. See the File Manager documentation for a description of the FSSpec data type.
specInto

If this parameter is a file, it specifies the resulting image. If this parameter is a folder, it specifies the location of the resulting image which will have the same name as the original file. If this parameter is not provided, the original file is modified. See the File Manager documentation for a description of the FSSpec data type.
repl

A Boolean value. If a file with the same name already exists, it will be replaced if this parameter is set to true. 
embProf

The profile to embed in the image. 
Return Value

A CMError value. See “ColorSync Manager Result Codes”.
Availability
Available in CarbonLib 1.0 and later when ColorSync 2.6 or later is present. 
Declared In
CMScriptingPlugin.h*/

CMError CMEmbedImage (
   const FSSpec * specFrom,
   const FSSpec * specInto,
   Boolean repl,
   CMProfileRef embProf
);


#ifdef __cplusplus
}
#endif

#endif